@@ -152,7 +152,7 @@ def default_cover_icons(cols=5):
         del extra[0]
         count += 1
 
-def create_cover(report, icons=(), cols=5, size=60, padding=8):
+def create_cover(report, icons=(), cols=5, size=120, padding=16):
     icons = icons or tuple(default_cover_icons(cols))
     rows = int(math.ceil(len(icons) / cols))
     with Canvas(cols * (size + padding), rows * (size + padding), bgcolor='#eee') as canvas:
@@ -497,7 +497,7 @@ class Delegate(QStyledItemDelegate):
         pixmap = index.data(Qt.DecorationRole)
         if pixmap and not pixmap.isNull():
             rect = option.rect.adjusted(0, self.SPACING, COVER_SIZE[0] - option.rect.width(), - self.SPACING)
-            painter.drawPixmap(rect, pixmap, pixmap.rect())
+            painter.drawPixmap(rect, pixmap)
         if option.state & QStyle.State_Selected:
             painter.setPen(QPen(QApplication.instance().palette().highlightedText().color()))
         bottom = option.rect.bottom() - 2
@@ -690,6 +690,7 @@ class ChooseTheme(Dialog):
         theme['cover-pixmap'] = p = QPixmap()
         if isinstance(cdata, bytes):
             p.loadFromData(cdata)
+            p.setDevicePixelRatio(self.devicePixelRatio())
         item = self.item_from_name(theme['name'])
         if item is not None:
             item.setData(Qt.DecorationRole, p)
