@@ -19,7 +19,7 @@ from PyQt5.Qt import (
     QMimeData, QUrl, QDrag, QPoint, QPainter, QRect, pyqtProperty, QEvent,
     QPropertyAnimation, QEasingCurve, pyqtSlot, QHelpEvent, QAbstractItemView,
     QStyleOptionViewItem, QToolTip, QByteArray, QBuffer, QBrush, qRed, qGreen,
-    qBlue, QItemSelectionModel)
+    qBlue, QItemSelectionModel, QIcon)
 
 from calibre import fit_image, prints, prepare_string_for_xml, human_readable
 from calibre.constants import DEBUG, config_dir
@@ -420,11 +420,11 @@ class CoverDelegate(QStyledItemDelegate):
         if raw_icon is not None:
             ans = raw_icon.pixmap(sz, sz)
         elif name == ':ondevice':
-            ans = QPixmap(I('ok.png')).scaled(sz, sz, transformMode=Qt.SmoothTransformation)
+            ans = QIcon(I('ok.png')).scaled(sz, sz)
         elif name:
-            pmap = QPixmap(os.path.join(config_dir, 'cc_icons', name))
+            pmap = QIcon(os.path.join(config_dir, 'cc_icons', name)).pixmap(sz, sz)
             if not pmap.isNull():
-                ans = pmap.scaled(sz, sz)
+                ans = pmap
         cache[name] = ans
         return ans
 
@@ -486,8 +486,10 @@ class CoverDelegate(QStyledItemDelegate):
                     rect.setBottom(rect.bottom() - self.title_height)
                 if self.animating is not None and self.animating.row() == index.row():
                     cdata = cdata.scaled(cdata.size() * self._animated_size)
-                dx = max(0, int((rect.width() - cdata.width())/2.0))
-                dy = max(0, rect.height() - cdata.height())
+                dpr = cdata.devicePixelRatio()
+                cw, ch = int(cdata.width() / dpr), int(cdata.height() / dpr)
+                dx = max(0, int((rect.width() - cw)/2.0))
+                dy = max(0, rect.height() - ch)
                 right_adjust = dx
                 rect.adjust(dx, dy, -dx, 0)
                 painter.drawPixmap(rect, cdata)
@@ -513,7 +515,7 @@ class CoverDelegate(QStyledItemDelegate):
                 try:
                     p = self.on_device_emblem
                 except AttributeError:
-                    p = self.on_device_emblem = QPixmap(I('ok.png')).scaled(48, 48, transformMode=Qt.SmoothTransformation)
+                    p = self.on_device_emblem = QIcon(I('ok.png')).pixmap(48, 48)
                 self.paint_embossed_emblem(p, painter, orect, right_adjust, left=False)
         finally:
             painter.restore()
@@ -542,21 +544,23 @@ class CoverDelegate(QStyledItemDelegate):
                 delta = 0 if i == 0 else self.emblem_size + self.MARGIN
                 grect.moveLeft(grect.left() + delta) if horizontal else grect.moveTop(grect.top() + delta)
                 rect = QRect(grect)
-                rect.setWidth(emblem.width()), rect.setHeight(emblem.height())
+                rect.setWidth(int(emblem.width() / emblem.devicePixelRatio())), rect.setHeight(int(emblem.height() / emblem.devicePixelRatio()))
                 painter.drawPixmap(rect, emblem)
         finally:
             painter.restore()
 
     def paint_embossed_emblem(self, pixmap, painter, orect, right_adjust, left=True):
         drect = QRect(orect)
+        pw = int(pixmap.width() / pixmap.devicePixelRatio())
+        ph = int(pixmap.height() / pixmap.devicePixelRatio())
         if left:
             drect.setLeft(drect.left() + right_adjust)
-            drect.setRight(drect.left() + pixmap.width())
+            drect.setRight(drect.left() + pw)
         else:
             drect.setRight(drect.right() - right_adjust)
-            drect.setLeft(drect.right() - pixmap.width() + 1)
+            drect.setLeft(drect.right() - pw + 1)
         drect.setBottom(drect.bottom() - self.title_height)
-        drect.setTop(drect.bottom() - pixmap.height())
+        drect.setTop(drect.bottom() - ph)
         painter.drawPixmap(drect, pixmap)
 
     @pyqtSlot(QHelpEvent, QAbstractItemView, QStyleOptionViewItem, QModelIndex, result=bool)
@@ -623,8 +627,9 @@ class GridView(QListView):
         self.padding_left = 0
         self.set_color()
         self.ignore_render_requests = Event()
+        dpr = self.devicePixelRatio()
         self.thumbnail_cache = ThumbnailCache(max_size=gprefs['cover_grid_disk_cache_size'],
-            thumbnail_size=(self.delegate.cover_size.width(), self.delegate.cover_size.height()))
+            thumbnail_size=(int(dpr * self.delegate.cover_size.width()), int(dpr * self.delegate.cover_size.height())))
         self.render_thread = None
         self.update_item.connect(self.re_render, type=Qt.QueuedConnection)
         self.doubleClicked.connect(self.double_clicked)
@@ -723,7 +728,8 @@ class GridView(QListView):
             self.setSpacing(self.delegate.spacing)
         self.set_color()
         if size_changed:
-            self.thumbnail_cache.set_thumbnail_size(self.delegate.cover_size.width(), self.delegate.cover_size.height())
+            dpr = self.devicePixelRatio()
+            self.thumbnail_cache.set_thumbnail_size(int(dpr * self.delegate.cover_size.width()), int(dpr*self.delegate.cover_size.height()))
         cs = gprefs['cover_grid_disk_cache_size']
         if (cs*(1024**2)) != self.thumbnail_cache.max_size:
             self.thumbnail_cache.set_size(cs)
@@ -787,6 +793,8 @@ class GridView(QListView):
         if has_cover:
             p = QImage()
             p.loadFromData(cdata, CACHE_FORMAT if cdata is tcdata else 'JPEG')
+            dpr = self.devicePixelRatio()
+            p.setDevicePixelRatio(dpr)
             if p.isNull() and cdata is tcdata:
                 # Invalid image in cache
                 self.thumbnail_cache.invalidate((book_id,))
@@ -796,11 +804,13 @@ class GridView(QListView):
             if not use_cache:  # cache is stale
                 if cdata is not None:
                     width, height = p.width(), p.height()
-                    scaled, nwidth, nheight = fit_image(width, height, self.delegate.cover_size.width(), self.delegate.cover_size.height())
+                    scaled, nwidth, nheight = fit_image(
+                        width, height, int(dpr * self.delegate.cover_size.width()), int(dpr * self.delegate.cover_size.height()))
                     if scaled:
                         if self.ignore_render_requests.is_set():
                             return
                         p = p.scaled(nwidth, nheight, Qt.IgnoreAspectRatio, Qt.SmoothTransformation)
+                        p.setDevicePixelRatio(dpr)
                     cdata = p
                 # update cache
                 if cdata is None:
